@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import logging
 import datetime
-from decimal import Decimal
 
 from starken.connector import Connector, ConnectorException
 from starken.settings import api_settings
@@ -29,7 +28,7 @@ class StarkenHandler:
             an appropriate structure for Starken courier.
         """
         split_name = instance.customer.full_name.split()
-        value_declared = sum([Decimal(item.price) for item in instance.items])
+        value_declared = sum([float(item.price) for item in instance.items])
         payload = {
             "rutEmpresaEmisora": api_settings.SENDER['RUT_COMPANY'],
             "rutUsuarioEmisor": api_settings.STARKEN['RUT_USER'],
@@ -51,7 +50,7 @@ class StarkenHandler:
             "numeroCtaCte": api_settings.SENDER['CTA_CTE_NUMBER'],
             "dvNumeroCtaCte": api_settings.SENDER['DV_CTA_CTE_NUMBER'],
             "centroCostoCtaCte": api_settings.SENDER['CENTER_COST_CTA_CTE'],
-            "valorDeclarado": str(value_declared),
+            "valorDeclarado": round(value_declared),
             "contenido": instance.reference,
             "kilosTotal": "1",
             "alto": "1",
@@ -103,14 +102,21 @@ class StarkenHandler:
         """
 
         url = f'{self.base_url}'
-        logger.debug(data)
-
         try:
             response = self.connector.post(url, data)
-            response.update({
-                'tracking_number': response['nroOrdenFlete'],
-            })
-            return response
+            logger.debug(response)
+
+            if response['codigoError'] == 0:
+                response.update({
+                    'tracking_number': response['nroOrdenFlete'],
+                })
+                return response
+            else:
+                raise ConnectorException(
+                    response['descripcionError'],
+                    response['descripcionError'],
+                    response['codigoError']
+                )
 
         except ConnectorException as error:
             logger.error(error)
